body{margin:0;font-family:sans-serif}*{box-sizing:border-box}a{text-decoration:none}code{font-family:monospace;background-color:#eaeaea;padding:3px 5px;border-radius:4px}#page-container{position:relative;width:100%}#page-container:before{content:"";position:absolute;width:100%;height:100%;z-index:999;background:no-repeat url("data:image/svg+xml,%3csvg%20version='1.1'%20id='L9'%20xmlns='http://www.w3.org/2000/svg'%20xmlns:xlink='http://www.w3.org/1999/xlink'%20x='0px'%20y='0px'%20viewBox='0%200%20100%20100'%20enable-background='new%200%200%200%200'%20xml:space='preserve'%3e%3cpath%20fill='%23aaa'%20d='M73,50c0-12.7-10.3-23-23-23S27,37.3,27,50%20M30.9,50c0-10.5,8.5-19.1,19.1-19.1S69.1,39.5,69.1,50'%3e%3canimateTransform%20attributeName='transform'%20attributeType='XML'%20type='rotate'%20dur='1s'%20from='0%2050%2050'%20to='360%2050%2050'%20repeatCount='indefinite'%3e%3c/animateTransform%3e%3c/path%3e%3c/svg%3e");background-size:100px;background-position:center center;pointer-events:none;opacity:0}body.page-is-transitioning #page-container:before{opacity:1}#page-content,#page-container:before{transition:opacity .5s ease-in-out}body.page-is-transitioning #page-content{opacity:.17}#sidebar a{padding:2px 10px;margin-left:-10px}#sidebar a.is-active{background-color:#eee}
